@@ -5,15 +5,18 @@
     :copyright: (c) 2012-2013 by Openlabs Technologies & Consulting (P) LTD
     :license: GPLv3, see LICENSE for more details.
 """
-from trytond.model import ModelSQL, ModelView, fields
+from trytond.model import ModelSQL, fields
+from trytond.pool import PoolMeta
 from nereid import login_required, request, flash, redirect, url_for
 
+__all__ = ['NereidUser', 'NereidUserParty', 'Party']
+__metaclass__ = PoolMeta
 
-class NereidUser(ModelSQL, ModelView):
+
+class NereidUser:
     "Nereid User"
-    _name = "nereid.user"
+    __name__ = "nereid.user"
 
-    display_name = fields.Char('Display Name', required=True, select=True)
     party = fields.Many2One(
         'party.party', 'Party', required=True, ondelete='RESTRICT',
         select=True, depends=['parties'],
@@ -24,19 +27,20 @@ class NereidUser(ModelSQL, ModelView):
         help="Parties to which this user is related"
     )
 
-    def create(self, values):
+    @classmethod
+    def create(cls, values):
         """
         Add the current party of the user to the list of parties allowed for
         the user automatically
         """
-        user_id = super(NereidUser, self).create(values)
+        user = super(NereidUser, cls).create(values)
         if 'parties' not in values:
-            user = self.browse(user_id)
-            self.write(user_id, {'parties': [('add', [user.party.id])]})
-        return user_id
+            cls.write([user], {'parties': [('add', [user.party.id])]})
+        return user
 
+    @classmethod
     @login_required
-    def change_party(self, party_id):
+    def change_party(cls, party_id):
         """
         Updates the current party of the nereid_user to the new party_id if
         it is one of the parties in the list of parties of the user
@@ -45,7 +49,7 @@ class NereidUser(ModelSQL, ModelView):
         """
         for party in request.nereid_user.parties:
             if party.id == party_id:
-                self.write(request.nereid_user.id, {'party': party.id})
+                cls.write([request.nereid_user], {'party': party.id})
                 break
         else:
             flash("The party is not valid")
@@ -53,13 +57,10 @@ class NereidUser(ModelSQL, ModelView):
             request.args.get('next', url_for('nereid.website.home'))
         )
 
-NereidUser()
-
 
 class NereidUserParty(ModelSQL):
     "Nereid User - Party"
-    _name = "nereid.user-party.party"
-    _description = __doc__
+    __name__ = "nereid.user-party.party"
 
     nereid_user = fields.Many2One(
         'nereid.user', 'Nereid User', ondelete='CASCADE',
@@ -70,18 +71,15 @@ class NereidUserParty(ModelSQL):
         select=True, required=True
     )
 
-NereidUserParty()
 
 
-class Party(ModelSQL, ModelView):
+class Party:
     """
     Party
     """
-    _name = "party.party"
+    __name__ = "party.party"
 
     nereid_users = fields.Many2Many(
         'nereid.user-party.party', 'party', 'nereid_user', 'Nereid Users',
         help="Nereid Users which have access to this party"
     )
-
-Party()
